@@ -55,7 +55,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "3.3.0"
+#define GM_VERSION                 "3.3.1"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               65536
@@ -293,12 +293,6 @@ typedef struct gm_job_struct {
     int            has_been_sent;       /**< flag if job has been sent back */
 } gm_job_t;
 
-
-/** options structure */
-mod_gm_opt_t *mod_gm_opt;
-gm_job_t * current_job;
-char hostname[GM_SMALLBUFSIZE];
-
 /*
  * @}
  */
